<?php

namespace App\Controllers;

use App\Libraries\BoardFn;          
// Fn(Function을 명칭으로 사용하면 클래스 자체가 차단됨)
use App\Libraries\PageCriteria;
use App\Libraries\PagingLogic;
use CodeIgniter\HTTP\IncomingRequest;


class Board extends BaseController
{
    public function __construct(){
        helper('url');
        helper('form');
    }

    public function index()
    {
        return view('board/index');
    }

    private function isBoardEmpty($boardname){
        
        $boardFn = new BoardFn();
        $boardFn->setBoardname($boardname);
        
        return $boardFn->isBoardname();
    }

    /*
    if (! is_file(APPPATH . 'Views/board/' . $page . '.php')) {
        
        echo "참";
        throw new \CodeIgniter\Exceptions\PageNotFoundException($page);
    }

    $data['title'] = ucfirst($page);

    return view('board/templates/header', $data)
        . view('board/' . $page)
        . view('board/templates/footer');
    */
    
    public function view($page = 'home', $aritcle_id = '0'){

        // if (! is_file(APPPATH . 'Views/board/view.php')) {
        //     throw new \CodeIgniter\Exceptions\PageNotFoundException($page);
        // }
    
        $data['title'] = ucfirst($page);
        $data['article_id'] = $aritcle_id;
    
        return view('board/templates/header', $data)
            . view('board/view', $data)
            . view('board/templates/footer');

    }

    public function list($boardname = ''){

        if( $this->isBoardEmpty($boardname) ){
        
            $db = \Config\Database::connect();  // DB 연결

            $data['title'] = '목록';
            $data['boardname'] = $boardname;

            // 페이징 로직 생성
            $pagingLogic = new PagingLogic();
            $pageCri = new PageCriteria();

            // 전체 게시글 갯수
            $board_total_cnt_qry = $db->query('select count(*) as `cnt` from cake_board_' . $boardname);
            $board_total_cnt = 0;

            if ( isset($_GET['page']) ){
                $page_no = $_GET['page'];
            }else{
                $page_no = 1;
            }

            // 페이지 설정
            if ($page_no >= 0 && 
                is_numeric($page_no)){

                $pageCri->setPage($page_no);
            }
            
            // 전체 갯수
            foreach($board_total_cnt_qry->getResult() as $item){
                $board_total_cnt = $item->cnt;
            }
            
            // 현재 페이지 구하기
            $page_size = $pageCri->getPerPageNum();
            
            $pagingLogic->setPageNo($page_no);
            $pagingLogic->setPageSize($page_size);
            $pagingLogic->setTotalCount($board_total_cnt);
            
            $pagingObj = $pagingLogic->getObject();
            $start_num = $pagingLogic->getDbStartNum();
            $end_num = $pagingLogic->getDbEndNum();

            // 오라클 페이징(자바 버전)
            //paramMap.put("startnum", startnum);		
            //paramMap.put("endnum", endnum);			
            
            // mariaDB(MySQL) 페이징(PHP 버전)
            if ( $start_num === 1) {
                $_start_num = 0;
            }
            else {
                $_start_num = $start_num - 1;
            }
                
            $_limnum = ( $end_num - $start_num ) + 1;

            $board_paging_qry = "SELECT b_id, b_subject, " . 
                                "b_content, b_author, " . 
                                "b_file_exist, b_cnt, " . 
                                "b_ip, b_regidate " . 
                                "FROM cake_board_" . $boardname . " " .
                                "ORDER BY cake_board_" . $boardname . ".b_is_notice DESC, " . 
                                "cake_board_" . $boardname . ".b_regidate DESC " . 
                                "LIMIT :lim_num: OFFSET :start_num:";

            // 게시판 바인딩
            $board_binding['lim_num'] = $_limnum;
            $board_binding['start_num'] = $_start_num;

            // 게시판 목록 가져오기
            $boardList = $db->query($board_paging_qry, $board_binding);

            // 데이터 값 전송
            $data['board_list'] = $boardList->getResult();
            $data['board_paging'] = $pagingLogic;

            // 제약조건
            $restrictOption = ['saveData' => false];    // 뷰에서 데이터값 - 공유 제약
        
            // 다중 뷰
            return view('board/templates/header', $data, $restrictOption)
                . view('board/list', $data, $restrictOption)
                . view('common/paging', $data, $restrictOption)
                . view('board/list_footer', $data, $restrictOption)
                . view('board/templates/footer', $data, $restrictOption);
                
        }else{
            throw new \CodeIgniter\Exceptions\PageNotFoundException($page);
        }

    }

    public function write($boardname){
        
        $session = session();

        if( $this->isBoardEmpty($boardname) ){
            
            $session->set('token', md5(uniqid(mt_rand(), true)));
            
            // 데이터 값 전송
            $data['title'] = "글쓰기";
            $data['boardname'] = $boardname; 
            $data['my_id'] = $session->get('token');

            // 제약조건
            $restrictOption = ['saveData' => false];    // 뷰에서 데이터값 - 공유 제약

            return view('board/templates/header', $data, $restrictOption)
                . view('board/write', $data, $restrictOption)
                . view('board/templates/footer', $data, $restrictOption);
        }else{
            $data['title'] = $boardname;
            return view('common/board_error', $data);
        }

    }

    public function write_ok($boardname){

        $status = 1;
        $token = $_POST['token'];
        $session = session();
        $validation = \Config\Services::validation();

        // 게시판이 존재할 때
        if( $this->isBoardEmpty($boardname) ){
            $status = 1;

        }else{
            $status = 2;
        }

        // CSRF 토큰 일치 여부 판단
        if ( $status === 1 ){
            
            if (!$token || $token !== $session->get('token')) {
                // return 405 http status code
                //header($_SERVER['SERVER_PROTOCOL'] . ' 405 Method Not Allowed');
                //exit;
                $status = 3;
            } else {
                // process the form
                $status = 1;
            }

        }

        //echo $token . "/" . $session->get('token') . "/" . $status;

        if ($status === 1){

            // 유효성 규칙 설정
            $validation->setRules(
                [
                    'b_subject' => 'required|is_unique[cake_board_' . $boardname . '.b_subject]',
                    'b_content' => 'required|min_length[10]',
                ],
                [   // Errors
                    'b_subject' => [
                        'required' => 'Subject is required',
                        'is_unique' => '중복될 수 없다',
                    ],
                    'b_content' => [
                        'min_length' => 'Content is very short.',
                    ],
                ]
            );


            if ( $validation->withRequest($this->request)->run() ){

                $db = \Config\Database::connect();  // DB 연결
                $request = service('request');

                // 게시판 Insert 쿼리
                $board_insert_qry = "insert into cake_board_dd(" . 
                                    "b_subject, b_content, b_is_notice, " . 
                                    "b_author, b_member_id, b_passwd, " . 
                                    "b_file_exist, b_comment_cnt, b_cnt, " . 
                                    "b_ip, b_regidate) " . 
                                    "VALUES(" . 
                                    ":b_subject:, :b_content:, :b_is_notice:, " . 
                                    ":b_author:, :b_member_id:, :b_passwd:, " . 
                                    ":b_file_exist:, :b_comment_cnt:, :b_cnt:, " . 
                                    ":b_ip:, :b_regidate:)";
                
                // 데이터 값
                $board_bind['b_subject'] = $request->getPost('b_subject');
                $board_bind['b_content'] = $request->getPost('b_content');
                $board_bind['b_is_notice'] = $request->getPost('b_is_notice');
                $board_bind['b_author'] = $request->getPost('b_author');
                $board_bind['b_member_id'] = $request->getPost('b_member_id');
                $board_bind['b_passwd'] = $request->getPost('b_passwd');
                $board_bind['b_file_exist'] = 0;
                $board_bind['b_comment_cnt'] = 0;
                $board_bind['b_cnt'] = 0;
                $board_bind['b_ip'] = "";
                $board_bind['b_regidate'] = date("Y-m-d H:i:s");

                // $request->getGet('');도 있음
                // ($_GET[''] = 강화버전)

                //print_r($board_bind);

                // 쿼리 실행
                $db->query($board_insert_qry, $board_bind);

                $data['title'] = $boardname;
                
                $this->response->redirect('board/' . $boardname . '/list');

            }else{
                $data['title'] = $boardname;
                $data["validation"] = $validation;
                return view('board/write_success', $data);
            }


        }
        else if ($status === 2){
            $data['title'] = $boardname;
            return view('common/board_error', $data);

        }
        else if ($status === 3){

        }

    }

}
